@@ -12,9 +12,10 @@ exporting tourneys data in a portable format.
 Scarry used an ``INI`` file and we had several drawbacks with it, mainly
 because sending them with e-mail would result in data corruption.
 
-SoL uses YAML_ instead, by default compressing the outcome with gzip.
+SoL uses YAML_ or JSON_ instead, by default compressing the outcome with gzip.
 
 .. _YAML: http://yaml.org/
+.. _JSON: http://json.org/
 """
 
 from datetime import datetime
@@ -30,6 +31,7 @@ from urllib.request import urlopen
 import logging
 import zipfile
 
+from metapensiero.sqlalchemy.proxy.json import py2json, json2py
 from yaml import safe_dump_all, safe_load_all
 
 from sqlalchemy import func
@@ -514,6 +516,8 @@ class Deserializer(object):
         if 'season' in stourney:
             # SoL 3 renamed “season” to “championship”
             stc = stourney.pop('season')
+            # but in SoL 2 there was also a “championship”, now gone
+            stourney.pop('championship', None)
         else:
             stc = stourney.pop('championship')
         if isinstance(stc, dict):
@@ -713,7 +717,7 @@ class Deserializer(object):
 
 
 def backup(sasess, pdir, edir, location=None, keep_only_if_changed=True,
-           only_played_tourneys=False):
+           only_played_tourneys=False, serialization_format='yaml'):
     """Dump almost everything in a ZIP file.
 
     :param sasess: a SQLAlchemy session
@@ -722,6 +726,7 @@ def backup(sasess, pdir, edir, location=None, keep_only_if_changed=True,
     :param location: either None or a string
     :param keep_only_if_changed: a boolean flag
     :param only_played_tourneys: a boolean flag
+    :param serialization_format: a string, either ``yaml`` or ``json``
     :rtype: bytes
     :return: the ZIP archive
 
@@ -744,6 +749,8 @@ def backup(sasess, pdir, edir, location=None, keep_only_if_changed=True,
     dump.
     """
 
+    logger.debug('Backing up whole database...')
+
     if location is None:
         backupfn = mktemp(prefix='sol')
     else:
@@ -772,16 +779,19 @@ def backup(sasess, pdir, edir, location=None, keep_only_if_changed=True,
         serializer.addRate(rate)
 
     # Dump all played tourneys, possibly ignoring those "in preparation", i.e. without matches
-    for tourney in sasess.query(Tourney) \
-                         .order_by(Tourney.date):
+    for tourney in sasess.query(Tourney).order_by(Tourney.date):
         if not only_played_tourneys or tourney.rankedturn > 0:
             serializer.addTourney(tourney)
 
-    yaml = safe_dump_all(serializer.dump())
+    dump = serializer.dump()
+    if serialization_format == 'yaml':
+        data = safe_dump_all(dump)
+    else:
+        data = py2json(list(dump))
 
     content = open(mktemp(prefix='sol'), 'w')
     try:
-        content.write(yaml)
+        content.write(data)
         content.close()
         modified = serializer.modified.timestamp()
         utime(content.name, (modified, modified))
@@ -908,10 +918,12 @@ def load_sol(sasess, url=None, content=None, restore=False, idowner=None):
     if url and url.endswith('.sol.gz'):
         content = GzipFile(fileobj=content, mode='rb')
 
-    yaml = content.read()
+    data = content.read()
 
     deserializer = Deserializer(sasess, idowner, not restore)
-    deserializer.load(safe_load_all(yaml))
+    deserializer.load(json2py(data)
+                      if data.startswith(b'[' if isinstance(data, bytes) else '[')
+                      else safe_load_all(data))
 
     for rating in deserializer.ratings:
         mindate = None
@@ -925,14 +937,15 @@ def load_sol(sasess, url=None, content=None, restore=False, idowner=None):
     return deserializer.tourneys, deserializer.skipped
 
 
-def dump_sol(tourneys, gzipped=False):
-    """Dump tourneys as a YAML document.
+def dump_sol(tourneys, gzipped=False, serialization_format='yaml'):
+    """Dump tourneys as a YAML or JSON document.
 
     :param tourneys: the sequence of tourneys to dump
     :param gzipped: a boolean indicating whether the output will be compressed
                     with ``gzip``
+    :param serialization_format: a string, either ``yaml`` or ``json``
     :rtype: bytes
-    :return: the YAML document, possibly gzipped
+    :return: the YAML/JSON document, possibly gzipped
     """
 
     serializer = Serializer()
@@ -940,16 +953,20 @@ def dump_sol(tourneys, gzipped=False):
     for tourney in tourneys:
         serializer.addTourney(tourney)
 
-    yaml = safe_dump_all(serializer.dump())
+    dump = serializer.dump()
+    if serialization_format == 'yaml':
+        data = safe_dump_all(dump)
+    else:
+        data = py2json(list(dump))
 
     if gzipped:
         out = BytesIO()
         gzipped = GzipFile(fileobj=out, mode='wb')
-        gzipped.write(yaml.encode('utf-8'))
+        gzipped.write(data.encode('utf-8'))
         gzipped.close()
-        yaml = out.getvalue()
+        data = out.getvalue()
 
-    return yaml
+    return data
 
 
 def _save_image(dir, fname, data, clogger):
@@ -1028,11 +1045,13 @@ def save_changes(sasess, request, modified, deleted, clogger=changes_logger):
         pdir = settings['sol.portraits_dir']
         edir = settings['sol.emblems_dir']
         user_id = request.session['user_id']
+        is_ownersadmin = request.session['is_ownersadmin']
     else:
         # tests
         from tempfile import gettempdir
         edir = pdir = gettempdir()
         user_id = None
+        is_ownersadmin = False
 
     # Perform insertions after updates: this is to handle the corner
     # case on competitors in team events, when a player can be moved
@@ -1076,7 +1095,7 @@ def save_changes(sasess, request, modified, deleted, clogger=changes_logger):
         else:
             instance = sasess.query(entity).get(idrecord)
             if instance is not None:
-                if user_id is not None:
+                if not is_ownersadmin:
                     if hasattr(entity, 'idowner') and instance.idowner != user_id:
                         # Abort current transaction
                         doom()
