@@ -271,7 +271,9 @@ class Championship(GloballyUnique, Base):
                 skipped = None
             totalprizes.append((players, sum(pts), prizes, nprizes, skipped))
 
-        return dates, sorted(totalprizes, key=lambda i: (-i[1], -i[3]))
+        return dates, sorted(totalprizes, key=lambda i: (
+            # Order by total points, number of tourneys, lastname, firstname
+            -i[1], -i[3], [p and (p.lastname, p.firstname) for p in i[0]]))
 
     def serialize(self, serializer):
         """Reduce a single championship to a simple dictionary.
