@@ -130,12 +130,20 @@ class Match(Base):
                                                      self.score1, self.score2)
         return r
 
-    def caption(self, html=None, localized=True):
+    def caption(self, html=None, localized=True, omit_competitor_decoration=False):
         "A description of the match, made up with the description of each competitor."
 
-        comp1 = self.competitor1.caption(html, localized)
+        # This is needed to overcome the simple xml parser used by reportlab,
+        # that chokes on span attributes
+        if omit_competitor_decoration:
+            c1_class = c2_class = None
+        else:
+            c1_class = 'c1'
+            c2_class = 'c2'
+
+        comp1 = self.competitor1.caption(html, localized, css_class=c1_class)
         if self.competitor2:
-            comp2 = self.competitor2.caption(html, localized)
+            comp2 = self.competitor2.caption(html, localized, css_class=c2_class)
         else:
             # TRANSLATORS: this is the name used for the "missing"
             # player, when there's an odd number of them
