@@ -186,6 +186,14 @@ class Player(GloballyUnique, Base):
                   hint=N_('ID of the user that is responsible for this record.')))
     """ID of the :py:class:`user <.Player>` that is responsible for this record."""
 
+    ownersadmin = Column(
+        boolean_t,
+        nullable=False,
+        default=False,
+        info=dict(label=N_('Owners Admin'),
+                  hint=N_('Whether the player can change ownership of other items.')))
+    """Whether the player can change ownership of other items."""
+
     ## Relations
 
     merged = relationship('MergedPlayer', backref='player',
@@ -487,7 +495,7 @@ class Player(GloballyUnique, Base):
                 return False
         return True
 
-    def caption(self, html=None, localized=True):
+    def caption(self, html=None, localized=True, css_class=None):
         "Description of the player, made up concatenating his names."
 
         if self.shouldOmitNickName():
@@ -502,6 +510,8 @@ class Player(GloballyUnique, Base):
                 format = N_('<b>$lastname</b> $firstname $nickname')
             else:
                 format = N_('$lastname $firstname $nickname')
+        if (html is None or html) and css_class:
+            format = '<span class="%s">%s</span>' % (css_class, format)
         return _(format, just_subst=not localized, mapping=dict(
             lastname=self.lastname,
             firstname=self.firstname,
@@ -561,8 +571,8 @@ class Player(GloballyUnique, Base):
                     # check is needed, just take note of the fact
 
                     if s.execute(select([mpt.c.idmergedplayer])
-                                 .where(mpt.c.guid == id_or_guid)
-                                 .where(mpt.c.idplayer == self.idplayer)).first() is not None:
+                                 .where(mpt.c.guid == id_or_guid)).first() is not None:
+                        # We already know she's been merged
                         continue
 
                     if isinstance(other_player, (tuple, list)):
