@@ -6,6 +6,7 @@
 #
 
 from collections import namedtuple
+from itertools import combinations
 import logging
 
 from sqlalchemy import Column, ForeignKey, Index, Sequence, func
@@ -118,9 +119,10 @@ class Tourney(GloballyUnique, Base):
         default='serial',
         info=dict(label=N_(u'Pairings'),
                   hint=N_('Method used to pair competitors at each round.'),
-                  dictionary=dict(serial=N_('Ranking order'),
+                  dictionary=dict(all=N_('All possible matches'),
+                                  serial=N_('Ranking order'),
                                   dazed=N_('Cross ranking order'))))
-    """Kind of pairing method used to build next round. It may be `serial` or `dazed`."""
+    "Kind of pairing method used to build next round. It may be `all`, `serial` or `dazed`."
 
     delaytoppairing = Column(
         smallint_t,
@@ -330,8 +332,7 @@ class Tourney(GloballyUnique, Base):
         """
 
         if self.prized:
-            raise OperationAborted(
-                _('Cannot update rankings after prize-giving!'))
+            raise OperationAborted(_('Cannot update rankings after prize-giving!'))
 
         ranking = dict(self.computeRanking())
 
@@ -433,7 +434,7 @@ class Tourney(GloballyUnique, Base):
 
         if self.finalturns:
             self.currentturn = self._makeNextFinalTurn()
-        elif self.idrating is not None or cturn:
+        elif self.idrating is not None or cturn or self.couplings == 'all':
             if cturn and cturn != self.rankedturn:
                 self.updateRanking()
             # If the tourney is using a rating, create the first round
@@ -467,7 +468,7 @@ class Tourney(GloballyUnique, Base):
             l -= 2
             b += 1
 
-    def _serialVisitor(self, pivot, competitors, skip):
+    def _serialVisitor(self, pivot, competitors, done):
         """Visit the `competitors` in order.
 
         :param pivot: a :py:class:`.Competitor>` instance
@@ -484,10 +485,10 @@ class Tourney(GloballyUnique, Base):
         """
 
         for i, c in enumerate(competitors):
-            if c is not pivot and (pivot, c) not in skip:
+            if c is not pivot and (pivot, c) not in done:
                 yield i
 
-    def _dazedVisitor(self, pivot, competitors, skip):
+    def _dazedVisitor(self, pivot, competitors, done):
         """Visit the `competitors`, giving precedence to the competitors with the same points.
 
         :param pivot: a :py:class:`.Competitor>` instance
@@ -525,7 +526,7 @@ class Tourney(GloballyUnique, Base):
 
         for i in positions:
             c = competitors[i]
-            if c is not pivot and (pivot, c) not in skip:
+            if c is not pivot and (pivot, c) not in done:
                 yield i
 
     def _combine(self, competitors, done, _level=0):
@@ -561,7 +562,7 @@ class Tourney(GloballyUnique, Base):
         else:
             debug = None
 
-        if len(competitors)<2:
+        if len(competitors) < 2:
             if debug:
                 debug("Backtracking: no more combinations")
             return None
@@ -665,7 +666,11 @@ class Tourney(GloballyUnique, Base):
         if len(activecomps) % 2:
             activecomps.append(None)
 
-        combination = self._combine(activecomps, done)
+        if self.couplings == 'all':
+            combination = self._makeNextAAATurn(activecomps, done)
+        else:
+            combination = self._combine(activecomps, done)
+
         phantommatch = None
         if combination:
             matches = []
@@ -695,10 +700,50 @@ class Tourney(GloballyUnique, Base):
 
             self.matches.extend(matches)
         else:
+            if self.couplings != 'all':
+                remaining = self._countRemainingMatches(activecomps, done)
+                if remaining:
+                    raise OperationAborted(
+                        _("Cannot create next round: there are further $remaining possible"
+                          " matches but they cannot be grouped together with the current"
+                          " pairing rules. Nevertheless, you can switch to the “All"
+                          " possible matches” method to generate remaining rounds.",
+                          mapping=dict(remaining=remaining)))
             raise OperationAborted(
-                _("Cannot create another round: No more combinations!"))
+                _("Cannot create another round: no more possible combinations!"))
         return newturn
 
+    def _makeNextAAATurn(self, competitors, done):
+        "Mechanically generate next turn out of all possible matches."
+
+        nextround = []
+        maxmatches = len(competitors) // 2
+        playing = set()
+
+        for c1, c2 in combinations(competitors, 2):
+            if (c1, c2) not in done:
+                if c1 not in playing and c2 not in playing:
+                    nextround.append((c1, c2))
+                    if len(nextround) == maxmatches:
+                        break
+                    playing.add(c1)
+                    playing.add(c2)
+
+        return nextround
+
+    def _countRemainingMatches(self, competitors, done):
+        remaining = 0
+        playing = set()
+
+        for c1, c2 in combinations(competitors, 2):
+            if (c1, c2) not in done:
+                if c1 not in playing and c2 not in playing:
+                    remaining += 1
+                    playing.add(c1)
+                    playing.add(c2)
+
+        return remaining
+
     def makeFinalTurn(self):
         "Generate the final matches."
 
@@ -760,6 +805,8 @@ class Tourney(GloballyUnique, Base):
         if self.rating is not None:
             self.rating.recompute(self.date)
 
+        logger.info('Assigned final prizes for %r', self)
+
     def _assignAsisPrizes(self):
         "Assign decreasing integer numbers as final prizes, down to 1 to the last competitor."
 
