@@ -92,11 +92,21 @@ def njoin(elts, stringify=asunicode, localized=True):
       >>> assert njoin([]) == ''
       >>> print(njoin([1,2], stringify=lambda x: str(x*10)))
       10 and 20
+
+    Note that *falsey* elements are skipped::
+
+      >>> print(njoin(['first', None, False, '', 'last']))
+      first and last
+
+    but ``0`` (*zero*) isn't considered a *falsey* value::
+
+      >>> print(njoin([1,0,2]))
+      1, 0 and 2
     """
 
     from ..i18n import gettext as _
 
-    elts = [stringify(e) for e in elts if e]
+    elts = [stringify(e) for e in elts if e or (e == 0 and e is not False)]
     if not elts:
         return ''
     elif len(elts) == 1:
