@@ -11,7 +11,8 @@ This module uses ReportLab to produce all the needed printouts.
 
 from copy import copy
 from datetime import date, datetime, timedelta
-import locale, logging
+import logging
+
 from babel.numbers import format_decimal
 
 logger = logging.getLogger(__name__)
@@ -219,16 +220,17 @@ class BasicPrintout(object):
         :param request: the Pyramid request instance
         :rtype: a sequence of arguments
         """
-        # pragma: no cover
-        raise NotImplementedError("%s should implement this method!" % klass)
 
-    def __init__(self, output, columns):
+        return [getattr(request, '_LOCALE_', 'en')]
+
+    def __init__(self, output, locale, columns):
         """Initialize the instance.
 
         :param output: a filename where the PDF will be written
         :param columns: number of columns
         """
 
+        self.locale = locale
         self.output = output
         self.columns = columns
         self.timestamp = datetime.now()
@@ -398,27 +400,32 @@ class TourneyPrintout(BasicPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
 
         id = request.matchdict['id']
-        try:
-            idtourney = int(id)
-        except ValueError:
-            try:
-                entity = session.query(Tourney).filter_by(guid=id).one()
-            except NoResultFound:
-                raise OperationAborted(t(_('No tourney with guid $id',
-                                           mapping=dict(id=id))))
+        if id == 'blank':
+            entity = None
         else:
-            entity = session.query(Tourney).get(idtourney)
-            if entity is None:
-                raise OperationAborted(t(_('No tourney with id $id',
-                                           mapping=dict(id=str(idtourney)))))
+            try:
+                idtourney = int(id)
+            except ValueError:
+                try:
+                    entity = session.query(Tourney).filter_by(guid=id).one()
+                except NoResultFound:
+                    raise OperationAborted(t(_('No tourney with guid $id',
+                                               mapping=dict(id=id))))
+            else:
+                entity = session.query(Tourney).get(idtourney)
+                if entity is None:
+                    raise OperationAborted(t(_('No tourney with id $id',
+                                               mapping=dict(id=str(idtourney)))))
 
-        return [entity]
+        args.append(entity)
+        return args
 
-    def __init__(self, output, tourney, columns):
-        super(TourneyPrintout, self).__init__(output, columns)
+    def __init__(self, output, locale, tourney, columns):
+        super(TourneyPrintout, self).__init__(output, locale, columns)
         self.tourney = tourney
 
     @property
@@ -471,13 +478,19 @@ class TourneyPrintout(BasicPrintout):
         yield FrameBreak()
         yield NextPageTemplate('laterPages')
 
+    def format_prize(self, prize):
+        if self.tourney.championship.prizes != 'centesimal':
+            return format_decimal(prize, '###0', self.locale)
+        else:
+            return format_decimal(prize, '###0.00', self.locale)
+
 
 class Participants(TourneyPrintout):
     "List of partecipants of a tourney."
 
-    def __init__(self, output, tourney):
-        super(Participants, self).__init__(
-            output, tourney, len(tourney.competitors)<35 and 1 or 2)
+    def __init__(self, output, locale, tourney):
+        super(Participants, self).__init__(output, locale, tourney,
+                                           len(tourney.competitors)<35 and 1 or 2)
 
     def getSubTitle(self):
         num = len(self.tourney.competitors)
@@ -557,10 +570,9 @@ class Ranking(TourneyPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
         kw = request.params
-        args = super().getArgumentsFromRequest(session, request)
-        args.append(getattr(request, '_LOCALE_', 'en'))
         if 'turn' in kw:
             try:
                 args.append(int(kw['turn']))
@@ -570,9 +582,8 @@ class Ranking(TourneyPrintout):
                         mapping=dict(turn=repr(kw['turn'])))))
         return args
 
-    def __init__(self, output, tourney, locale, turn=None):
-        super(Ranking, self).__init__(output, tourney, 1)
-        self.locale = locale
+    def __init__(self, output, locale, tourney, turn=None):
+        super(Ranking, self).__init__(output, locale, tourney, 1)
         self.turn = turn
 
     def getLitURL(self, request):
@@ -624,26 +635,19 @@ class Ranking(TourneyPrintout):
     def getElements(self):
         yield from super(Ranking, self).getElements()
 
-        def player_caption(player, html, localized):
-            caption = player.caption(html=html, localized=localized)
+        def player_caption(player, html, localized, css_class=None):
+            caption = player.caption(html=html, localized=localized, css_class=css_class)
             if player.club:
                 caption += "<font size=6> %s</font>" % player.club
             return caption
 
-        if self.tourney.championship.prizes in ('asis', 'fixed', 'fixed40', 'millesimal'):
-            def format_prize(p):
-                return '%d' % p
-        else:
-            def format_prize(p):
-                return format_decimal(p, '###0.00', self.locale)
-
         if self.turn is not None:
             ranking = [(i, c.caption(player_caption=player_caption), c.nationality,
                         r.points, r.bucholz, r.netscore, 0)
                        for i, (c, r) in enumerate(self.tourney.computeRanking(self.turn), 1)]
         else:
             ranking = [(i, c.caption(player_caption=player_caption), c.nationality,
-                        c.points, c.bucholz, c.netscore, format_prize(c.prize))
+                        c.points, c.bucholz, c.netscore, self.format_prize(c.prize))
                        for i, c in enumerate(self.tourney.ranking, 1)]
 
             if self.tourney.finals and self.tourney.prized:
@@ -800,9 +804,9 @@ class NationalRanking(TourneyPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
         kw = request.params
-        args = super().getArgumentsFromRequest(session, request)
         if 'turn' in kw:
             try:
                 args.append(int(kw['turn']))
@@ -812,8 +816,8 @@ class NationalRanking(TourneyPrintout):
                         mapping=dict(turn=repr(kw['turn'])))))
         return args
 
-    def __init__(self, output, tourney, turn=None):
-        super(NationalRanking, self).__init__(output, tourney, 1)
+    def __init__(self, output, locale, tourney, turn=None):
+        super(NationalRanking, self).__init__(output, locale, tourney, 1)
         self.turn = turn
 
     def getSubTitle(self):
@@ -981,9 +985,9 @@ class Results(TourneyPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
         kw = request.params
-        args = super().getArgumentsFromRequest(session, request)
         if 'turn' in kw:
             if kw['turn'] == 'all':
                 args.append(None)
@@ -995,12 +999,12 @@ class Results(TourneyPrintout):
                         t(_('Invalid turn: $turn',
                             mapping=dict(turn=repr(kw['turn'])))))
         else:
-            args.append(args[0].rankedturn)
+            args.append(args[1].rankedturn)
 
         return args
 
-    def __init__(self, output, tourney, turn):
-        super(Results, self).__init__(output, tourney, 1)
+    def __init__(self, output, locale, tourney, turn):
+        super(Results, self).__init__(output, locale, tourney, 1)
         self.turn = turn
 
     def getLitURL(self, request):
@@ -1024,7 +1028,9 @@ class Results(TourneyPrintout):
 
         turn = self.turn
 
-        results = [(m.turn, m.board, m.description, m.score1, m.score2, m.final)
+        results = [(m.turn, m.board,
+                    m.caption(omit_competitor_decoration=True),
+                    m.score1, m.score2, m.final)
                    for m in self.tourney.matches
                    if not turn or m.turn == turn]
         if not results:
@@ -1084,8 +1090,8 @@ class Results(TourneyPrintout):
 class Matches(TourneyPrintout):
     "Next turn matches."
 
-    def __init__(self, output, tourney):
-        super(Matches, self).__init__(output, tourney, 1)
+    def __init__(self, output, locale, tourney):
+        super(Matches, self).__init__(output, locale, tourney, 1)
 
     def getSubTitle(self):
         if self.tourney.finalturns:
@@ -1097,7 +1103,7 @@ class Matches(TourneyPrintout):
         yield from super(Matches, self).getElements()
 
         currentturn = self.tourney.currentturn
-        turn = [(m.board, m.description)
+        turn = [(m.board, m.caption(omit_competitor_decoration=True))
                 for m in self.tourney.matches
                 if m.turn==currentturn]
         if not turn:
@@ -1128,9 +1134,9 @@ class ScoreCards(TourneyPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         if request.matchdict['id'] != 'blank':
             t = translator(request)
-            args = super().getArgumentsFromRequest(session, request)
             kw = request.params
             if 'starttime' in kw:
                 try:
@@ -1142,12 +1148,10 @@ class ScoreCards(TourneyPrintout):
                     raise OperationAborted(
                         t(_('Invalid starttime: $starttime',
                             mapping=dict(starttime=repr(kw['starttime'])))))
-            return args
-        else:
-            return [None]
+        return args
 
-    def __init__(self, output, tourney, starttime=None, columns=2):
-        super(ScoreCards, self).__init__(output, tourney, columns)
+    def __init__(self, output, locale, tourney, starttime=None, columns=2):
+        super(ScoreCards, self).__init__(output, locale, tourney, columns)
         self.starttime = starttime
 
     @property
@@ -1351,10 +1355,11 @@ class Badges(object):
                 raise OperationAborted(t(_('No tourney with id $id',
                                            mapping=dict(id=str(idtourney)))))
 
-        return [entity]
+        return [getattr(request, '_LOCALE_', 'en'), entity]
 
-    def __init__(self, output, tourney):
+    def __init__(self, output, locale, tourney):
         self.output = output
+        self.locale = locale
         self.tourney = tourney
 
     @property
@@ -1366,6 +1371,12 @@ class Badges(object):
         else:
             return 0
 
+    def format_prize(self, prize):
+        if self.tourney.championship.prizes != 'centesimal':
+            return format_decimal(prize, '###0', self.locale)
+        else:
+            return format_decimal(prize, '###0.00', self.locale)
+
     def getPlayers(self):
         if self.tourney.prized:
             competitors = self.tourney.ranking
@@ -1554,9 +1565,19 @@ class Badges(object):
             c.drawRightString(3.1*cm, h, str(myscore))
             c.drawRightString(3.4*cm, h, str(otherscore))
 
+        c.drawRightString(1.9*cm, 1.1*cm, gettext('Points:'))
+        c.drawRightString(2.7*cm, 1.1*cm, str(competitor.points))
+        c.drawRightString(1.9*cm, 0.8*cm, gettext('Bucholz:'))
+        c.drawRightString(2.7*cm, 0.8*cm, str(competitor.bucholz))
+        c.drawRightString(1.9*cm, 0.5*cm, gettext('Net score:'))
+        c.drawRightString(2.7*cm, 0.5*cm, str(competitor.netscore))
+        if self.tourney.championship.prizes != 'asis':
+            c.drawRightString(1.9*cm, 0.2*cm, gettext('Bounty:'))
+            c.drawRightString(2.7*cm, 0.2*cm, self.format_prize(competitor.prize))
+
         c.drawCentredString(6.0*cm, self.height-1*cm,
                             gettext('Final ranking'))
-        c.drawString(3.8*cm, self.height-1.25*cm,
+        c.drawString(3.7*cm, self.height-1.25*cm,
                      gettext('Competitor'))
         if self.tourney.championship.prizes == 'asis':
             # TRANSLATORS: this is the points in the badge
@@ -1581,13 +1602,13 @@ class Badges(object):
         else:
             # TRANSLATORS: this is the points in the badge
             pts = gettext('pts')
-            c.drawRightString(6.9*cm, self.height-1.25*cm, pts)
+            c.drawRightString(6.8*cm, self.height-1.25*cm, pts)
             # TRANSLATORS: this is the bucholz in the badge
             bch = gettext('bch')
-            c.drawRightString(7.3*cm, self.height-1.25*cm, bch)
+            c.drawRightString(7.2*cm, self.height-1.25*cm, bch)
             # TRANSLATORS: this is the net score in the badge
             net = gettext('net')
-            c.drawRightString(7.75*cm, self.height-1.25*cm, net)
+            c.drawRightString(7.7*cm, self.height-1.25*cm, net)
             # TRANSLATORS: this is the prize in the badge
             prz = gettext('prz')
             c.drawRightString(8.5*cm, self.height-1.25*cm, prz)
@@ -1596,12 +1617,12 @@ class Badges(object):
                 if i > 15:
                     break
                 h = self.height-1.6*cm-i*0.22*cm
-                c.drawRightString(3.8*cm, h, str(i+1))
-                c.drawString(3.9*cm, h, e(ctor.caption(html=False), 2.6*cm))
-                c.drawRightString(6.9*cm, h, str(ctor.points))
-                c.drawRightString(7.3*cm, h, str(ctor.bucholz))
-                c.drawRightString(7.75*cm, h, str(ctor.netscore))
-                c.drawRightString(8.5*cm, h, str(ctor.prize))
+                c.drawRightString(3.7*cm, h, str(i+1))
+                c.drawString(3.8*cm, h, e(ctor.caption(html=False), 2.6*cm))
+                c.drawRightString(6.8*cm, h, str(ctor.points))
+                c.drawRightString(7.2*cm, h, str(ctor.bucholz))
+                c.drawRightString(7.7*cm, h, str(ctor.netscore))
+                c.drawRightString(8.5*cm, h, self.format_prize(ctor.prize))
 
 
 class ChampionshipRanking(BasicPrintout):
@@ -1609,6 +1630,7 @@ class ChampionshipRanking(BasicPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
 
         id = request.matchdict['id']
@@ -1626,10 +1648,11 @@ class ChampionshipRanking(BasicPrintout):
                 raise OperationAborted(t(_('No championship with id $id',
                                            mapping=dict(id=str(idchampionship)))))
 
-        return [entity]
+        args.append(entity)
+        return args
 
-    def __init__(self, output, arg):
-        super(ChampionshipRanking, self).__init__(output, 1)
+    def __init__(self, output, locale, arg):
+        super(ChampionshipRanking, self).__init__(output, locale, 1)
         self.setup(arg)
 
     @property
@@ -1699,6 +1722,7 @@ class ChampionshipRanking(BasicPrintout):
                  ('LINEBELOW', (0,1), (-1,-1), 0.25, colors.black)]
         header.append(gettext('Total'))
         rows = [header]
+
         for i, c in enumerate(self.ranking):
             row = [i+1]
             row.append(njoin(c[0]))
@@ -1711,8 +1735,8 @@ class ChampionshipRanking(BasicPrintout):
                                       (col+2, i+1), (col+2, i+1),
                                       colors.lightgrey))
                     c[4].remove(s)
-                row.append(s and locale.format('%.2f', s) or '')
-            row.append(locale.format('%.2f', c[1]))
+                row.append(self.format_prize(s) if s else '')
+            row.append(self.format_prize(c[1]))
             rows.append(row)
         yield Table(rows, style=TableStyle(style))
 
@@ -1729,13 +1753,21 @@ class ChampionshipRanking(BasicPrintout):
             header.append(d.strftime(gettext('%m-%d-%y')))
         return header
 
+    def format_prize(self, prize):
+        if self.championship.prizes != 'centesimal':
+            return format_decimal(prize, '###0', self.locale)
+        else:
+            return format_decimal(prize, '###0.00', self.locale)
+
 
 class SinglesRanking(ChampionshipRanking):
     "General singles ranking."
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
-        return [session]
+        args = BasicPrintout.getArgumentsFromRequest(session, request)
+        args.append(session)
+        return args
 
     def setup(self, sasession):
         (self.championships, self.period,
@@ -1800,6 +1832,12 @@ class SinglesRanking(ChampionshipRanking):
 
         yield Table(rows, (rank_width, desc_width))
 
+    def format_prize(self, prize):
+        if self.championships[0][0].prizes != 'centesimal':
+            return format_decimal(prize, '###0', self.locale)
+        else:
+            return format_decimal(prize, '###0.00', self.locale)
+
 
 class DoublesRanking(SinglesRanking):
     "General doubles ranking."
@@ -1830,6 +1868,7 @@ class RatingRanking(BasicPrintout):
 
     @classmethod
     def getArgumentsFromRequest(klass, session, request):
+        args = super().getArgumentsFromRequest(session, request)
         t = translator(request)
 
         id = request.matchdict['id']
@@ -1847,13 +1886,13 @@ class RatingRanking(BasicPrintout):
                 raise OperationAborted(t(_('No rating with id $id',
                                            mapping=dict(id=str(idrating)))))
 
-        return [entity, getattr(request, '_LOCALE_', 'en')]
+        args.append(entity)
+        return args
 
-    def __init__(self, output, rating, locale):
-        super().__init__(output, 1)
+    def __init__(self, output, locale, rating):
+        super().__init__(output, locale, 1)
         self.rating = rating
         self.ranking = rating.ranking
-        self.locale = locale
 
     @property
     def cache_max_age(self):
