@@ -32,8 +32,12 @@ def create_config(args):
         return update_config(args)
 
     alembicdir = join(dirname(dirname(sol.__file__)), 'alembic')
+    datadir = args.data_dir
     secret = hexlify(urandom(20)).decode('ascii')
-    password = input('Choose a password for the "admin" user: ')
+    admin = args.admin
+    password = args.password
+    if not password:
+        password = input('Choose a password for the "%s" super user: ' % admin)
     if not password:
         password = hexlify(urandom(5)).decode('ascii')
         random_password = True
@@ -44,12 +48,12 @@ def create_config(args):
         configuration = f.read()
 
     with open(args.config, 'w', encoding='utf-8') as f:
-        f.write(configuration.format(secret=secret, password=password,
-                                     alembicdir=alembicdir))
+        f.write(configuration.format(secret=secret, admin=admin, password=password,
+                                     alembicdir=alembicdir, datadir=datadir))
 
     print('The configuration file "%s" has been successfully created' % args.config)
-    print('The password for the admin user is "%s"%s' % (
-        password, ", you should change it!" if random_password else ""))
+    print('The password for the "%s" super user is "%s"%s' % (
+        admin, password, ", you should change it!" if random_password else ""))
 
 
 def update_config(args):
@@ -62,29 +66,39 @@ def update_config(args):
         print('The config file "%s" does not exists!' % args.config)
         return None
 
-    alembicdir = join(dirname(dirname(sol.__file__)), 'alembic')
-
     with open(args.config, 'r', encoding='utf-8') as f:
         configuration = f.read()
 
-    alembicdir_re = re.compile(r'script_location\s*=\s*(.+)\s*$')
+    substitutions = [(re.compile(r'script_location\s*=\s*(.+)\s*$'),
+                      join(dirname(dirname(sol.__file__)), 'alembic'),
+                      'script_location = %s')]
+    if args.admin is not None:
+        substitutions.append((re.compile(r'sol\.admin\.user\s*=\s*(.+)\s*$'),
+                              args.admin,
+                              'sol.admin.user = %s'))
+    if args.password is not None:
+        substitutions.append((re.compile(r'sol\.admin\.password\s*=\s*(.+)\s*$'),
+                              args.password,
+                              'sol.admin.password = %s'))
 
+    updated = False
     lines = configuration.splitlines()
     for pos, line in enumerate(lines):
-        match = alembicdir_re.match(line)
-        if match:
-            if match.group(1) == alembicdir:
-                print('The config file "%s" is already up-to-date!' % args.config)
-                return None
+        for rx, value, repl in substitutions:
+            match = rx.match(line)
+            if match is not None:
+                if match.group(1) != value:
+                    lines[pos] = repl % value
+                    updated = True
 
-            lines[pos] = 'script_location = ' + alembicdir
-            break
+    if updated:
+        with open(args.config, 'w', encoding='utf-8') as f:
+            f.write('\n'.join(lines))
+            f.write('\n')
 
-    with open(args.config, 'w', encoding='utf-8') as f:
-        f.write('\n'.join(lines))
-        f.write('\n')
-
-    print('The configuration file "%s" has been successfully updated' % args.config)
+        print('The configuration file "%s" has been successfully updated' % args.config)
+    else:
+        print('The configuration file "%s" is already up-to-date!' % args.config)
 
 
 def initialize_db(args):
@@ -157,9 +171,9 @@ def restore_all(args):
             args.url = abspath(args.url)
         backup_url = args.url
     else:
-        backup_url = args.url + 'bio/backup'
+        backup_url = args.url + 'bio/backup?serialization_format=json'
         if not args.all:
-            backup_url += '?only_played_tourneys=1'
+            backup_url += '&only_played_tourneys=1'
 
     print("Loading backup from %s..." % backup_url)
 
@@ -411,11 +425,22 @@ def main():
 
     subp = subparsers.add_parser('create-config',
                                  help=create_config.__doc__)
+    subp.add_argument('-a', '--admin', default='admin',
+                      help="Specify the name of the super user, “admin”"
+                      " by default")
+    subp.add_argument('-p', '--password', help="Specify the admin password,"
+                      " if not set you will be prompted for one")
+    subp.add_argument('-d', '--data-dir', default='%(here)s',
+                      help="Directory where data (db, emblems, portraits, backups and logs)"
+                      " will be stored, by default the one containing the configuration file")
     subp.add_argument('config', help="Name of the new configuration file")
     subp.set_defaults(func=create_config)
 
     subp = subparsers.add_parser('update-config',
                                  help=update_config.__doc__)
+    subp.add_argument('-a', '--admin',
+                      help="Specify the new name of the super user")
+    subp.add_argument('-p', '--password', help="Specify the new admin password")
     subp.add_argument('config', help="Name of the existing configuration file")
     subp.set_defaults(func=update_config)
 
