@@ -311,6 +311,7 @@ Ext.define('SoL.module.Championships', {
     ],
     uses: [
         'SoL.module.Championships.Actions',
+        'SoL.module.Players',
         'SoL.window.Help'
     ],
 
@@ -330,7 +331,11 @@ Ext.define('SoL.module.Championships', {
         clicksToEdit: 0,
         dataURL: '/data/championships',
         saveChangesURL: '/bio/saveChanges',
-        sorters: ['closed', 'description']
+        sorters: ['closed', 'description'],
+        stripeRows: true,
+        selModel: {
+            mode: 'MULTI'
+        }
     },
 
     getConfig: function(callback) {
@@ -352,9 +357,10 @@ Ext.define('SoL.module.Championships', {
                     successProperty: metadata.success_slot,
                     rootProperty: metadata.root_slot,
                     plugins: [
-                        Ext.create('SoL.module.Championships.Actions', {
-                            module: me
-                        })
+                        Ext.create('SoL.module.Championships.Actions',
+                                   { module: me }),
+                        Ext.create('SoL.module.Players.AssignOwnership',
+                                   { module: me }),
                     ]
                 });
                 callback(cfg);
@@ -380,7 +386,7 @@ Ext.define('SoL.module.Championships', {
         me.configure(
             [me.getConfig],
             function(done) {
-                var size = desktop.getReasonableWindowSize(650, 421, "SW");
+                var size = desktop.getReasonableWindowSize(720, 421, "SW");
                 var filteredOn;
 
                 config = Ext.apply({
