@@ -402,6 +402,7 @@ Ext.define('SoL.module.Clubs', {
     ],
     uses: [
         'SoL.module.Clubs.Actions',
+        'SoL.module.Players',
         'SoL.form.field.FlagsCombo',
         'SoL.window.Help'
     ],
@@ -422,7 +423,11 @@ Ext.define('SoL.module.Clubs', {
         clicksToEdit: 0,
         dataURL: '/data/clubs',
         saveChangesURL: '/bio/saveChanges',
-        sorters: ['description']
+        sorters: ['description'],
+        stripeRows: true,
+        selModel: {
+            mode: 'MULTI'
+        }
     },
 
     getConfig: function(callback) {
@@ -457,9 +462,10 @@ Ext.define('SoL.module.Clubs', {
                     successProperty: metadata.success_slot,
                     rootProperty: metadata.root_slot,
                     plugins: [
-                        Ext.create('SoL.module.Clubs.Actions', {
-                            module: me
-                        })
+                        Ext.create('SoL.module.Clubs.Actions',
+                                   { module: me }),
+                        Ext.create('SoL.module.Players.AssignOwnership',
+                                   { module: me })
                     ]
                 });
                 callback(cfg);
@@ -485,7 +491,7 @@ Ext.define('SoL.module.Clubs', {
         me.configure(
             [me.getConfig],
             function(done) {
-                var size = desktop.getReasonableWindowSize(650, 447, "NW");
+                var size = desktop.getReasonableWindowSize(700, 447, "NW");
 
                 if(idclub) {
                     config = Ext.apply({
