@@ -13,7 +13,8 @@
 Ext.define('SoL.module.Competitors', {
     extend: 'MP.desktop.Module',
     requires: [
-        'MP.grid.Panel'
+        'MP.grid.Panel',
+        'SoL.window.Help'
     ],
 
     id: 'competitors-win',
