@@ -13,6 +13,140 @@
 /*jsl:declare SoL*/
 /*jsl:declare FileReader*/
 
+Ext.define('SoL.module.Players.AssignOwnership', {
+    extend: 'MP.action.StoreAware',
+    uses: [
+        'Ext.Action',
+        'MP.form.Panel',
+        'MP.window.Notification'
+    ],
+
+    statics: {
+        ASSIGN_OWNERSHIP_ACTION: 'assign_ownership'
+    },
+
+    initActions: function() {
+        var me = this;
+        var ids = me.statics();
+
+        me.callParent();
+
+        me.assignOwnershipAction = me.addAction(new Ext.Action({
+            itemId: ids.ASSIGN_OWNERSHIP_ACTION,
+            text: _('Assign'),
+            tooltip: _('Assign ownership of selected records.'),
+            iconCls: 'owner-icon',
+            disabled: true,
+            needsSelectedRow: true,
+            handler: function() {
+                me.assignOwnership();
+            }
+        }));
+    },
+
+    attachActions: function() {
+        var me = this;
+
+        me.callParent();
+
+        if(me.module.app.user.is_admin || me.module.app.user.is_ownersadmin) {
+            var tbar = me.component.child('#ttoolbar');
+
+            tbar.add(tbar.items.length-3, me.assignOwnershipAction);
+        }
+    },
+
+    assignOwnership: function() {
+        var me = this;
+        var desktop = me.module.app.getDesktop();
+        var win;
+        var winWidth = 345;
+        var winHeight = 110;
+
+        var model = Ext.define('MP.data.ImplicitModel-'+Ext.id(), {
+            extend: 'Ext.data.Model',
+            fields: ['idplayer', 'Fullname'],
+            idProperty: 'idplayer'
+        });
+
+        var lstore = Ext.create('Ext.data.Store', {
+            model: model,
+            pageSize: 999,
+            autoLoad: false,
+            remoteFilter: true,
+            proxy: {
+                type: 'ajax',
+                url: '/data/owners',
+                filterParam: 'filters',
+                reader: {
+                    type: 'json',
+                    root: 'root',
+                    idProperty: 'idplayer'
+                }
+            }
+        });
+        lstore.implicitModel = true;
+
+        var form = new Ext.form.Panel({
+            frame: true,
+            bodyPadding: '10 10 0',
+            defaults: {
+                labelWidth: 90,
+                anchor: '100%'
+            },
+            items: [{
+                xtype: 'combo',
+                store: lstore,
+                valueField: 'idplayer',
+                displayField: 'Fullname',
+                buttonText: _('Browse'),
+                emptyText: _('Select responsible'),
+                allowBlank: false,
+                triggerAction: 'all',
+                typeAhead: true,
+                forceSelection: true,
+                fieldLabel: _('Owner')
+            }],
+            buttons: [{
+                text: _('Cancel'),
+                handler: function() {
+                    win.destroy();
+                }
+            }, {
+                text: _('Confirm'),
+                formBind: true,
+                handler: function() {
+                    var frm = form.getForm();
+                    if(frm.isValid()) {
+                        var combo = frm.getFields().getAt(0);
+                        var sels = me.component.getSelectionModel().getSelection();
+                        Ext.each(sels, function(record) {
+                            record.set('idowner', combo.value);
+                            record.set('Owner', combo.getRawValue());
+                        });
+                        win.destroy();
+                    }
+                }
+            }]
+        });
+
+        win = desktop.createWindow({
+            id: me.id,
+            title: _('Assign ownership'),
+            iconCls: 'upload-icon',
+            width: winWidth,
+            height: winHeight,
+            layout: 'fit',
+            minimizable: false,
+            maximizable: false,
+            modal: true,
+            items: [form]
+        });
+
+        win.show();
+    }
+});
+
 Ext.define('SoL.module.Players.Actions', {
     extend: 'MP.action.StoreAware',
     uses: [
@@ -217,6 +351,16 @@ Ext.define('SoL.module.Players.Actions', {
             nationality: { editor: { xtype: 'flagscombo' } },
             Language: { editor: { queryMode: 'local' } }
         });
+        var secondcoleditors = [
+            editors.Language,
+            editors.nationality,
+            editors.citizenship,
+            editors.Club,
+            editors.Federation,
+            editors.Owner
+        ];
+        if(me.module.app.user.is_admin || me.module.app.user.is_ownersadmin)
+            secondcoleditors.push(editors.ownersadmin);
         var form = Ext.create('MP.form.Panel', {
             autoScroll: true,
             fieldDefaults: {
@@ -238,22 +382,15 @@ Ext.define('SoL.module.Players.Actions', {
                         editors.password,
                         editors.sex,
                         editors.birthdate,
-                        editors.email
+                        editors.email,
+                        editors.phone
                     ]
                 }, {
                     xtype: 'container',
                     layout: 'anchor',
                     minHeight: 245,
                     flex: 1,
-                    items: [
-                        editors.phone,
-                        editors.Language,
-                        editors.nationality,
-                        editors.citizenship,
-                        editors.Club,
-                        editors.Federation,
-                        editors.Owner
-                    ]
+                    items: secondcoleditors
                 }, {
                     xtype: 'container',
                     style: 'text-align: center;',
@@ -389,6 +526,7 @@ Ext.define('SoL.module.Players', {
         'Ext.grid.plugin.DragDrop',
         'SoL.form.field.FlagsCombo',
         'SoL.module.Players.Actions',
+        'SoL.module.Players.AssignOwnership',
         'SoL.module.Players.MergePlugin',
         'SoL.window.Help'
     ],
@@ -508,9 +646,10 @@ Ext.define('SoL.module.Players', {
                     successProperty: metadata.success_slot,
                     rootProperty: metadata.root_slot,
                     plugins: [
-                        Ext.create('SoL.module.Players.Actions', {
-                            module: me
-                        })
+                        Ext.create('SoL.module.Players.Actions',
+                                   { module: me }),
+                        Ext.create('SoL.module.Players.AssignOwnership',
+                                   { module: me })
                     ]
                 });
                 callback(cfg);
@@ -553,7 +692,8 @@ Ext.define('SoL.module.Players', {
                                         '{0} selected', '{0} selected', num
                                     ), num) + ')';
                                 }
-                                win.setTitle(me.getLauncherText() + filteredOn + seltext);
+                                win.setTitle((me.windowTitle || me.getLauncherText())
+                                             + filteredOn + seltext);
                             }
                         }
                     }
