@@ -348,6 +348,7 @@ Ext.define('SoL.module.Ratings', {
         'MP.grid.Panel'
     ],
     uses: [
+        'SoL.module.Players',
         'SoL.module.Ratings.Actions',
         'SoL.window.Help'
     ],
@@ -368,7 +369,11 @@ Ext.define('SoL.module.Ratings', {
         clicksToEdit: 0,
         dataURL: '/data/ratings',
         saveChangesURL: '/bio/saveChanges',
-        sorters: ['description']
+        sorters: ['description'],
+        stripeRows: true,
+        selModel: {
+            mode: 'MULTI'
+        }
     },
 
     getConfig: function(callback) {
@@ -390,9 +395,10 @@ Ext.define('SoL.module.Ratings', {
                     successProperty: metadata.success_slot,
                     rootProperty: metadata.root_slot,
                     plugins: [
-                        Ext.create('SoL.module.Ratings.Actions', {
-                            module: me
-                        })
+                        Ext.create('SoL.module.Ratings.Actions',
+                                   { module: me }),
+                        Ext.create('SoL.module.Players.AssignOwnership',
+                                   { module: me })
                     ]
                 });
                 callback(cfg);
@@ -417,7 +423,7 @@ Ext.define('SoL.module.Ratings', {
         me.configure(
             [me.getConfig],
             function(done) {
-                var size = desktop.getReasonableWindowSize(690, 421, "S");
+                var size = desktop.getReasonableWindowSize(750, 421, "S");
 
                 me.config.newRecordData = {
                     tau: 0.5,
