@@ -217,6 +217,11 @@ Ext.define('SoL.module.Tourney', {
                 var idc = record.get('idcompetitor');
                 var mstore = mgrid.store;
 
+                if(mstore.isModified()) {
+                    // Don't do anything if the user is inserting round' scores
+                    return;
+                }
+
                 if(!mgrid.focusedCompetitor || mgrid.focusedCompetitor != idc) {
                     mgrid.setTitle(Ext.String.format(
                         _('Matches played by {0}'), record.get('description')));
