@@ -416,6 +416,7 @@ Ext.define('SoL.module.Tourneys', {
         'MP.grid.Panel'
     ],
     uses: [
+        'SoL.module.Players',
         'SoL.module.Tourneys.Actions',
         'SoL.window.Help'
     ],
@@ -437,7 +438,10 @@ Ext.define('SoL.module.Tourneys', {
         dataURL: '/data/tourneys',
         saveChangesURL: '/bio/saveChanges',
         sorters: [{property: 'date', direction: 'DESC'}],
-        stripeRows: true
+        stripeRows: true,
+        selModel: {
+            mode: 'MULTI'
+        }
     },
 
     getConfig: function(callback) {
@@ -460,6 +464,8 @@ Ext.define('SoL.module.Tourneys', {
                     rootProperty: metadata.root_slot,
                     plugins: [
                         Ext.create('SoL.module.Tourneys.Actions',
+                                   { module: me }),
+                        Ext.create('SoL.module.Players.AssignOwnership',
                                    { module: me })
                     ]
                 });
@@ -489,7 +495,7 @@ Ext.define('SoL.module.Tourneys', {
         me.configure(
             [me.getConfig],
             function(done) {
-                var size = desktop.getReasonableWindowSize(800, 421, "NE");
+                var size = desktop.getReasonableWindowSize(890, 421, "NE");
                 var filteredOn;
 
                 if(club) {
