@@ -148,70 +148,22 @@ Ext.define('SoL.view.Matches', {
             var r;
 
             switch(num) {
-                case 1:
-                    r = _('the first');
-                    break;
-
-                case 2:
-                    r = _('the second');
-                    break;
-
-                case 3:
-                    r = _('the third');
-                    break;
-
-                case 4:
-                    r = _('the fourth');
-                    break;
-
-                case 5:
-                    r = _('the fifth');
-                    break;
-
-                case 6:
-                    r = _('the sixth');
-                    break;
-
-                case 7:
-                    r = _('the seventh');
-                    break;
-
-                case 8:
-                    r = _('the eighth');
-                    break;
-
-                case 9:
-                    r = _('the nineth');
-                    break;
-
-                case 10:
-                    r = _('the tenth');
-                    break;
-
-                case 11:
-                    r = _('the eleventh');
-                    break;
-
-                case 12:
-                    r = _('the twelfth');
-                    break;
-
-                case 13:
-                    r = _('the thirdteenth');
-                    break;
-
-                case 14:
-                    r = _('the fourteenth');
-                    break;
-
-                case 15:
-                    r = _('the fifteenth');
-                    break;
-
-                case 16:
-                    r = _('the sixteenth');
-                    break;
-
+                case  1: r = _('the first'); break;
+                case  2: r = _('the second'); break;
+                case  3: r = _('the third'); break;
+                case  4: r = _('the fourth'); break;
+                case  5: r = _('the fifth'); break;
+                case  6: r = _('the sixth'); break;
+                case  7: r = _('the seventh'); break;
+                case  8: r = _('the eighth'); break;
+                case  9: r = _('the nineth'); break;
+                case 10: r = _('the tenth'); break;
+                case 11: r = _('the eleventh'); break;
+                case 12: r = _('the twelfth'); break;
+                case 13: r = _('the thirdteenth'); break;
+                case 14: r = _('the fourteenth'); break;
+                case 15: r = _('the fifteenth'); break;
+                case 16: r = _('the sixteenth'); break;
                 default:
                     r = num+'';
                     break;
@@ -222,70 +174,22 @@ Ext.define('SoL.view.Matches', {
         ordinalp: function(num) {
             var r;
             switch(num) {
-                case 1:
-                    r = _('of the first');
-                    break;
-
-                case 2:
-                    r = _('of the second');
-                    break;
-
-                case 3:
-                    r = _('of the third');
-                    break;
-
-                case 4:
-                    r = _('of the fourth');
-                    break;
-
-                case 5:
-                    r = _('of the fifth');
-                    break;
-
-                case 6:
-                    r = _('of the sixth');
-                    break;
-
-                case 7:
-                    r = _('of the seventh');
-                    break;
-
-                case 8:
-                    r = _('of the eighth');
-                    break;
-
-                case 9:
-                    r = _('of the nineth');
-                    break;
-
-                case 10:
-                    r = _('of the tenth');
-                    break;
-
-                case 11:
-                    r = _('of the eleventh');
-                    break;
-
-                case 12:
-                    r = _('of the twelfth');
-                    break;
-
-                case 13:
-                    r = _('of the thirdteenth');
-                    break;
-
-                case 14:
-                    r = _('of the fourteenth');
-                    break;
-
-                case 15:
-                    r = _('of the fifteenth');
-                    break;
-
-                case 16:
-                    r = _('of the sixteenth');
-                    break;
-
+                case  1: r = _('of the first'); break;
+                case  2: r = _('of the second'); break;
+                case  3: r = _('of the third'); break;
+                case  4: r = _('of the fourth'); break;
+                case  5: r = _('of the fifth'); break;
+                case  6: r = _('of the sixth'); break;
+                case  7: r = _('of the seventh'); break;
+                case  8: r = _('of the eighth'); break;
+                case  9: r = _('of the nineth'); break;
+                case 10: r = _('of the tenth'); break;
+                case 11: r = _('of the eleventh'); break;
+                case 12: r = _('of the twelfth'); break;
+                case 13: r = _('of the thirdteenth'); break;
+                case 14: r = _('of the fourteenth'); break;
+                case 15: r = _('of the fifteenth'); break;
+                case 16: r = _('of the sixteenth'); break;
                 default:
                     r = num+'';
                     break;
@@ -362,10 +266,33 @@ Ext.define('SoL.view.Matches', {
                 }
             });
 
+            function decorate_winner(val, meta, record, rowIndex, colIndex, store) {
+                if(record.get('score1') > record.get('score2'))
+                    meta.tdCls += ' winner1';
+                else if(record.get('score1') < record.get('score2'))
+                    meta.tdCls += ' winner2';
+                return val;
+            };
+
+            function decorate_winner_c1(val, meta, record, rowIndex, colIndex, store) {
+                if(record.get('score1') > record.get('score2'))
+                    meta.tdCls += ' winner';
+                return val;
+            };
+
+            function decorate_winner_c2(val, meta, record, rowIndex, colIndex, store) {
+                if(record.get('score1') < record.get('score2'))
+                    meta.tdCls += ' winner';
+                return val;
+            };
+
             MP.data.MetaData.fetch(cfg.dataURL, me, function(metadata) {
                 var overrides = {
-                    score1: { editor: { hideTrigger: true } },
-                    score2: { editor: { hideTrigger: true } }
+                    description: { renderer: decorate_winner },
+                    score1: { renderer: decorate_winner_c1,
+                              editor: { hideTrigger: true } },
+                    score2: { renderer: decorate_winner_c2,
+                              editor: { hideTrigger: true } }
                 };
 
                 Ext.apply(cfg, {
@@ -663,7 +590,7 @@ Ext.define('SoL.view.Matches', {
         var me = this;
         var tourney = me.module.tourney;
         var url = '/pdf/scorecards/' + tourney.idtourney;
-        var win;
+        var win, form;
         var winWidth = 215;
         var winHeight = 110;
         var now = new Date();
@@ -678,7 +605,23 @@ Ext.define('SoL.view.Matches', {
             minValue = maxValue = undefined;
         }
 
-        var form = new Ext.form.Panel({
+        var handler = function() {
+            var frm = form.getForm();
+            if(frm.isValid()) {
+                var starttime = frm.getFields().items[0].getValue().getTime();
+                url += '?starttime=' + starttime;
+                win.destroy();
+                window.location.assign(url);
+            }
+        };
+
+        var onKeyDown = function(field, event) {
+            if (event.keyCode === event.RETURN || event.keyCode === 10) {
+                handler();
+            }
+        };
+
+        form = new Ext.form.Panel({
             frame: true,
             bodyPadding: '10 10 0',
             defaults: {
@@ -687,11 +630,18 @@ Ext.define('SoL.view.Matches', {
             },
             items: [{
                 xtype: 'timefield',
+                itemId: 'starttime',
                 increment: 5,
                 allowBlank: false,
                 minValue: minValue,
                 maxValue: maxValue,
-                value: Ext.Date.add(now, Ext.Date.MINUTE, 10 + (5 - now.getMinutes() % 5))
+                value: Ext.Date.add(now, Ext.Date.MINUTE, 10 + (5 - now.getMinutes() % 5)),
+                enableKeyEvents: true,
+                listeners: {
+                    keydown: onKeyDown,
+                    scope: me
+                }
+
             }],
             buttons: [{
                 text: _('Cancel'),
@@ -701,15 +651,7 @@ Ext.define('SoL.view.Matches', {
             }, {
                 text: _('Confirm'),
                 formBind: true,
-                handler: function() {
-                    var frm = form.getForm();
-                    if(frm.isValid()) {
-                        var starttime = frm.getFields().items[0].getValue().getTime();
-                        url += '?starttime=' + starttime;
-                        win.destroy();
-                        window.location.assign(url);
-                    }
-                }
+                handler: handler
             }]
         });
 
@@ -720,7 +662,8 @@ Ext.define('SoL.view.Matches', {
             layout: 'fit',
             minimizable: false,
             maximizable: false,
-            items: [form]
+            items: [form],
+            defaultFocus: 'starttime'
         });
 
         win.show();
