@@ -5,30 +5,44 @@
 # :Licenza:   GNU General Public License version 3 or later
 #
 
-from json import loads
 from webtest.app import AppError
 
+from metapensiero.sqlalchemy.proxy.json import py2json, json2py
+from yaml import safe_load_all
 
-from metapensiero.sqlalchemy.proxy.json import py2json
 from . import AuthenticatedTestCase, FunctionalTestCase
 
 
 class TestBackup(FunctionalTestCase):
-    def extract_tourneys(self, archive):
+    def extract_everything_sol(self, archive):
         from io import BytesIO
         import zipfile
-        from yaml import safe_load_all
 
         zipf = zipfile.ZipFile(BytesIO(archive), 'r')
-        content = BytesIO(zipf.read('everything.sol'))
+        return zipf.read('everything.sol')
+
+    def extract_tourneys_yaml(self, archive):
+        content = self.extract_everything_sol(archive)
         return list(safe_load_all(content))[1:]
 
+    def extract_tourneys_json(self, archive):
+        content = self.extract_everything_sol(archive)
+        return list(json2py(content))[1:]
+
     def test_backup(self):
         from ..data import TourneyData
 
         response = self.app.get('/bio/backup')
         self.assertEqual(response.content_type, 'application/zip')
-        tourneys = self.extract_tourneys(response.body)
+        tourneys = self.extract_tourneys_yaml(response.body)
+        self.assertEqual(len(tourneys), len(TourneyData.rows))
+
+    def test_backup_json(self):
+        from ..data import TourneyData
+
+        response = self.app.get('/bio/backup?serialization_format=json')
+        self.assertEqual(response.content_type, 'application/zip')
+        tourneys = self.extract_tourneys_json(response.body)
         self.assertEqual(len(tourneys), len(TourneyData.rows))
 
     def test_backup_played_tourneys(self):
@@ -38,7 +52,7 @@ class TestBackup(FunctionalTestCase):
 
         response = self.app.get('/bio/backup?only_played_tourneys=1')
         self.assertEqual(response.content_type, 'application/zip')
-        tourneys = self.extract_tourneys(response.body)
+        tourneys = self.extract_tourneys_yaml(response.body)
         self.assertEqual(len(tourneys), 0)
 
         s = DBSession()
@@ -49,7 +63,7 @@ class TestBackup(FunctionalTestCase):
 
         response = self.app.get('/bio/backup?only_played_tourneys=1')
         self.assertEqual(response.content_type, 'application/zip')
-        tourneys = self.extract_tourneys(response.body)
+        tourneys = self.extract_tourneys_yaml(response.body)
         self.assertEqual(len(tourneys), 1)
 
 
@@ -93,14 +107,14 @@ class TestGuestUploadViews(AuthenticatedTestCase):
             '/bio/upload',
             upload_files=[('portrait', 'foo.png', b"")])
         self.assertEqual(response.content_type, 'text/html')
-        self.assertEqual(loads(response.text)['success'], False)
+        self.assertEqual(json2py(response.text)['success'], False)
 
     def test_upload_emblem(self):
         response = self.app.post(
             '/bio/upload',
             upload_files=[('emblem', 'foo.png', b"")])
         self.assertEqual(response.content_type, 'text/html')
-        self.assertEqual(loads(response.text)['success'], False)
+        self.assertEqual(json2py(response.text)['success'], False)
 
     def test_upload_sol(self):
         from os.path import dirname, join
@@ -110,7 +124,7 @@ class TestGuestUploadViews(AuthenticatedTestCase):
             '/bio/upload',
             upload_files=[('archive', dump)])
         self.assertEqual(response.content_type, 'text/html')
-        self.assertEqual(loads(response.text)['success'], False)
+        self.assertEqual(json2py(response.text)['success'], False)
 
 
 class TestAdminUploadViews(AuthenticatedTestCase):
@@ -123,7 +137,7 @@ class TestAdminUploadViews(AuthenticatedTestCase):
             upload_files=[('portrait', 'bar.png', b"")])
         self.assertEqual(response.content_type, 'text/html')
         # Dropped support in 3.0
-        self.assertEqual(loads(response.text)['success'], False)
+        self.assertEqual(json2py(response.text)['success'], False)
 
     def test_upload_emblem(self):
         response = self.app.post(
@@ -131,7 +145,7 @@ class TestAdminUploadViews(AuthenticatedTestCase):
             upload_files=[('emblem', 'bar.png', b"")])
         self.assertEqual(response.content_type, 'text/html')
         # Dropped support in 3.0
-        self.assertEqual(loads(response.text)['success'], False)
+        self.assertEqual(json2py(response.text)['success'], False)
 
     def test_restore(self):
         from os.path import dirname, exists, join
@@ -141,7 +155,7 @@ class TestAdminUploadViews(AuthenticatedTestCase):
             '/bio/upload',
             upload_files=[('archive', dump)])
         self.assertEqual(response.content_type, 'text/html')
-        self.assertEqual(loads(response.text)['success'], True)
+        self.assertEqual(json2py(response.text)['success'], True)
         settings = self.app.app.registry.settings
         edir = settings['sol.emblems_dir']
         pdir = settings['sol.portraits_dir']
@@ -390,7 +404,7 @@ class TestProtectedUploadViews(AuthenticatedTestCase):
             '/bio/upload',
             upload_files=[('archive', dump)])
         self.assertEqual(response.content_type, 'text/html')
-        self.assertEqual(loads(response.text)['success'], True)
+        self.assertEqual(json2py(response.text)['success'], True)
 
         s = DBSession()
 
