@@ -199,21 +199,22 @@ class TestSerialization(TestCase):
             self.assertEqual(otherchampionship.previous.description,
                              onechampionship.description)
 
-    def test_full_dump_reload(self):
-        from io import StringIO
+    def test_full_dump_reload(self, serialization_format='yaml', gzip=False):
+        from io import BytesIO, StringIO
 
         s = models.DBSession()
 
         tourneys = s.query(models.Tourney).all()
         ntourneys = len(tourneys)
 
-        dump = dump_sol(tourneys, False)
+        dump = dump_sol(tourneys, gzip, serialization_format)
 
         models.wipe_database()
 
         s.expunge_all()
 
-        load_sol(s, 'dump.sol', StringIO(dump))
+        load_sol(s, 'dump.sol' + ('.gz' if gzip else ''),
+                 (BytesIO if gzip else StringIO)(dump))
         tourneys = s.query(models.Tourney).all()
         newntourneys = len(tourneys)
 
@@ -232,28 +233,18 @@ class TestSerialization(TestCase):
         self.assertEqual(p.citizenship, fata.citizenship)
         self.assertEqual(p.email, fata.email)
 
-        dump2 = dump_sol(tourneys, False)
-        self.assertEqual(dump, dump2)
+        if not gzip:
+            dump2 = dump_sol(tourneys, gzip, serialization_format)
+            self.assertEqual(dump, dump2)
 
     def test_full_dump_reload_gzip(self):
-        from io import BytesIO
+        self.test_full_dump_reload(gzip=True)
 
-        s = models.DBSession()
+    def test_full_dump_reload_json(self):
+        self.test_full_dump_reload(serialization_format='json')
 
-        tourneys = s.query(models.Tourney).all()
-        ntourneys = len(tourneys)
-
-        dump = dump_sol(tourneys, True)
-
-        models.wipe_database()
-
-        s.expunge_all()
-
-        load_sol(s, 'dump.sol.gz', BytesIO(dump))
-        tourneys = s.query(models.Tourney).all()
-        newntourneys = len(tourneys)
-
-        self.assertEqual(ntourneys, newntourneys)
+    def test_full_dump_reload_json_gzip(self):
+        self.test_full_dump_reload(serialization_format='json', gzip=True)
 
     def test_load_rated_tourney(self):
         from os.path import join, split
@@ -381,7 +372,7 @@ class TestBackup(TestCase):
     def test_plain_backup(self):
         backup(models.DBSession(), '/tmp', '/tmp', '/tmp')
 
-    def test_full_backup_restore(self):
+    def test_full_backup_restore(self, serialization_format='yaml'):
         from io import BytesIO
 
         s = models.DBSession()
@@ -413,6 +404,9 @@ class TestBackup(TestCase):
                .filter_by(firstname=PlayerData.lele.firstname).one()
         self.assertEqual(owned.owner, lele)
 
+    def test_full_backup_restore_json(self):
+        self.test_full_backup_restore('json')
+
 
 class TestReplay(TestCase):
     def test_update_incomplete_tourney(self):
@@ -522,3 +516,13 @@ class TestMerged(TestCase):
 
         self.assertRaises(NoResultFound,
                           s.query(models.Player).filter_by(guid=elene_guid).one)
+
+
+class TestVersion2ChampionshipAndSeason(TestCase):
+    def test_load(self):
+        from os.path import join, split
+
+        s = models.DBSession()
+
+        fullname = join(split(__file__)[0], 'scr', 'Mouraly-2016-03-19+6.sol')
+        load_sol(s, fullname)
