@@ -8,6 +8,7 @@
 from decimal import Decimal
 import logging
 from operator import attrgetter
+from random import randint
 
 import transaction
 from sqlalchemy.orm.exc import NoResultFound
@@ -385,7 +386,6 @@ class TestTourney(TestCase):
         self.assertEqual(len(t.matches), (len(t.competitors) + 1) // 2)
 
     def test_next_turn(self):
-        from random import randint
         s = models.DBSession()
         t = s.query(models.Tourney) \
             .filter_by(description=TourneyData.first.description).one()
@@ -430,8 +430,6 @@ class TestTourney(TestCase):
         self.assertEqual(len(t.matches), 24)
 
     def test_odd(self):
-        from random import randint
-
         s = models.DBSession()
         t = s.query(models.Tourney) \
             .filter_by(description=TourneyData.odd.description).one()
@@ -971,6 +969,68 @@ class TestTourneyResetPrizes(TestCase):
                                      date=TourneyData.rated.date).one)
 
 
+class TestTourneyAllAgainstAll(TestCase):
+    def test_all_against_all(self):
+        from os.path import join, split
+        from sol.models.bio import load_sol
+
+        s = models.DBSession()
+
+        # SoL was able to generate only three rounds
+
+        fullname = join(split(__file__)[0], 'scr',
+                        'Campionato_SCR_2015_2016-2016-04-24+3.sol.gz')
+        tourneys, skipped = load_sol(s, fullname)
+
+        t = tourneys[0]
+
+        self.assertRaises(OperationAborted, t.makeNextTurn)
+
+        t.resetPrizes()
+        s.flush()
+
+        # switch to all-against-all mode, to generate remaining three rounds
+        # with only two boards
+
+        t.couplings = 'all'
+
+        t.makeNextTurn()
+
+        nboards = 0
+        lastturn = t.currentturn
+        for m in t.matches:
+            if m.turn == lastturn:
+                m.score1 = randint(1, 25)
+                m.score2 = randint(1, 25)
+                nboards += 1
+
+        self.assertEqual(nboards, 2)
+
+        t.makeNextTurn()
+
+        nboards = 0
+        lastturn = t.currentturn
+        for m in t.matches:
+            if m.turn == lastturn:
+                m.score1 = randint(1, 25)
+                m.score2 = randint(1, 25)
+                nboards += 1
+
+        self.assertEqual(nboards, 2)
+
+        t.makeNextTurn()
+
+        nboards = 0
+        lastturn = t.currentturn
+        for m in t.matches:
+            if m.turn == lastturn:
+                m.score1 = randint(1, 25)
+                m.score2 = randint(1, 25)
+                nboards += 1
+
+        self.assertRaises(OperationAborted, t.makeNextTurn)
+
+
 class TestRetirement(TestCase):
     def test_retirement(self):
         s = models.DBSession()
