@@ -144,6 +144,7 @@ _players_metadata = dict(
     email=dict(hidden=True, vtype='email'),
     phone=dict(hidden=True, vtype='phone'),
     portrait=dict(hidden=True, width=130),
+    ownersadmin=dict(hidden=True, nullable=True),
     Club=dict(label=_clubs_t.c.description.info['label'],
               hint=_('The club this player is affiliated with.'),
               flex=1,
@@ -227,7 +228,7 @@ def players(request, results):
         for r in results['root']:
             code = r['language']
             if code:
-                r['Language'] = t(languages.get(alpha2=code).name)
+                r['Language'] = t(languages.get(iso639_1_code=code).name)
             r['password'] = '' if r['password'] == '*' else '*'
     return add_owner(request, results)
 
@@ -478,8 +479,8 @@ def languages(request):
         t = translation('iso639', LOCALES_DIR, languages=[lname]).gettext
     except IOError:
         t = lambda x: x
-    result = [dict(code=l.alpha2, name=t(l.name))
-              for l in languages if hasattr(l, 'alpha2')]
+    result = [dict(code=l.iso639_1_code, name=t(l.name))
+              for l in languages if hasattr(l, 'iso639_1_code')]
     return dict(count=len(result),
                 message="Ok",
                 root=sorted(result, key=itemgetter('name')),
