@@ -12,7 +12,7 @@ from pyramid.httpexceptions import HTTPBadRequest
 from sqlalchemy import select
 from sqlalchemy.orm.exc import NoResultFound
 
-from ..i18n import translatable_string as _, translator
+from ..i18n import translatable_string as _, gettext, ngettext, translator
 from ..models import DBSession, Player, Rate, Rating
 
 
@@ -100,12 +100,41 @@ def ratingChart(request):
     return response
 
 
+class MapValue(object):
+    def __init__(self, males, females):
+        self.males = males
+        self.females = females
+        self.players = males + females
+
+    def __str__(self):
+        if self.males and self.females:
+            p = ngettext('$count player', '$count players', self.players,
+                         mapping=dict(count=self.players))
+            m = ngettext('$count male', '$count males', self.males,
+                         mapping=dict(count=self.males))
+            f = ngettext('$count female', '$count females', self.females,
+                         mapping=dict(count=self.females))
+            return '%s\n(%s %s %s)' % (p, m, gettext('and'), f)
+        elif self.males:
+            return ngettext('$count male', '$count males', self.males,
+                            mapping=dict(count=self.males))
+        else:
+            return ngettext('$count female', '$count females', self.females,
+                            mapping=dict(count=self.females))
+
+    def __lt__(self, other):
+        return self.players < other.players
+
+    def __sub__(self, other):
+        return self.players + other.players
+
+
 @view_config(route_name="svg_playersdist")
 def playersDistribution(request):
     from gettext import translation
     from collections import Counter
     from pycountry import LOCALES_DIR, countries
-    import pygal
+    import pygal, pygal_maps_world
 
     width = int(request.params.get('width', 800))
     height = int(request.params.get('height', 600))
@@ -116,7 +145,7 @@ def playersDistribution(request):
     except IOError:
         ct = lambda x: x
 
-    pygal_countries = pygal.i18n.COUNTRIES
+    pygal_countries = pygal_maps_world.i18n.COUNTRIES
     for alpha2 in pygal_countries:
         try:
             c = countries.get(alpha2=alpha2.upper())
@@ -127,7 +156,7 @@ def playersDistribution(request):
 
     t = translator(request)
 
-    chart = pygal.Worldmap(show_legend=False, width=width, height=height)
+    chart = pygal.maps.world.World(show_legend=False, width=width, height=height)
     chart.title = t(_('Players distribution around the globe'))
 
     sas = DBSession()
@@ -145,14 +174,18 @@ def playersDistribution(request):
         except KeyError:
             pass
         else:
-            if sex == 'F':
-                counter = women
-            else:
-                counter = men
+            counter = women if sex == 'F' else men
             counter[country.alpha2.lower()] += 1
 
-    chart.add(t(_('Females')), women)
-    chart.add(t(_('Males')), men)
+    all_keys = set(men.keys()) | set(women.keys())
+    serie = {}
+
+    for key in all_keys:
+        m = men[key]
+        w = women[key]
+        serie[key] = MapValue(m, w)
+
+    chart.add(t(_('Players')), serie)
 
     response = request.response
     response.body = chart.render()
