@@ -129,16 +129,19 @@ def competitors(request, results):
         fields=('board,description,score1,score2,turn,final,'
                 'idmatch,idcompetitor1,idcompetitor2').split(','),
         metadata=dict(
+    board=dict(readonly=True, sortable=False, width=70),
     description=dict(label=_('Match'),
                      hint=_('Competitor 1 vs Competitor 2.'),
                      sortable=False,
                      readonly=True,
                      flex=1),
-    turn=dict(hidden=True, readonly=True, width=70),
-    board=dict(readonly=True, width=70),
-    score1=dict(width=70),
-    score2=dict(width=70),
-    final=dict(hidden=True, readonly=True),
+    score1=dict(sortable=False, width=70),
+    score2=dict(sortable=False, width=70),
+    turn=dict(hidden=True, readonly=True, sortable=False, width=70),
+    final=dict(hidden=True, readonly=True, sortable=False),
+    idmatch=dict(sortable=False),
+    idcompetitor1=dict(sortable=False),
+    idcompetitor2=dict(sortable=False),
     ))
 def matches(request, results):
     return results
@@ -370,6 +373,10 @@ def updateRanking(request):
 
         success = True
         message = 'Ok'
+    except OperationAborted as e: # pragma: no cover
+        message = str(e)
+        get_request_logger(request, logger).error("Couldn't update the ranking: %s", message)
+        success = False
     except Exception as e:
         message = str(e)
         get_request_logger(request, logger).critical("Couldn't update the ranking: %s",
